@@ -1,11 +1,11 @@
 
-# $Id: Ebay.pm,v 2.271 2015-09-13 14:28:54 Martin Exp $
-
 package WWW::Search::Ebay;
 
 use strict;
 use warnings;
 
+our $VERSION = 2.273;
+
 =head1 NAME
 
 WWW::Search::Ebay - backend for searching www.ebay.com
@@ -135,8 +135,6 @@ use WWW::Search qw( generic_option strip_tags );
 use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
-our
-$VERSION = 2.272;
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -527,6 +525,11 @@ sub _parse_shipping
   $iPrice =~ s!&Acirc;!!g;
   $iPrice =~ s!!!g;
   print STDERR " DDD   raw shipping ===$iPrice===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
+  if ($iPrice =~ m/UNKNOWN/i)
+    {
+    # No shipping info provided:
+    return 1;
+    } # if
   if ($iPrice =~ m/FREE/i)
     {
     $iPrice = 0.00;
@@ -1014,6 +1017,15 @@ sub _parse_tree
     push(@{$self->{cache}}, $hit);
     $self->{'_num_hits'}++;
     $iHits++;
+
+    if ($self->approximate_result_count() <= $iHits)
+      {
+      # We've already scraped all the hits that eBay said there were.
+      # Stop scraping, so that we don't return hits that are not an
+      # exact match to the query but are just "related":
+      last TD;
+      } # if
+
     # Delete this HTML element so that future searches go faster?
     $oTDtitle->detach;
     $oTDtitle->delete;
